@@ -1,13 +1,12 @@
-use std::convert::TryInto;
 use std::sync::Arc;
 
 use parquet_format_async_temp::{ColumnChunk, ColumnMetaData, Encoding};
 
 use super::column_descriptor::ColumnDescriptor;
+use crate::compression::Compression;
 use crate::error::Result;
-use crate::schema::types::{ParquetType, PhysicalType};
+use crate::schema::types::PhysicalType;
 use crate::statistics::{deserialize_statistics, Statistics};
-use crate::{compression::Compression, schema::types::Type};
 
 /// Metadata for a column chunk.
 // This contains the `ColumnDescriptor` associated with the chunk so that deserializers have
@@ -18,9 +17,9 @@ pub struct ColumnChunkMetaData {
     column_descr: ColumnDescriptor,
 }
 
-/// Represents common operations for a column chunk.
+// Represents common operations for a column chunk.
 impl ColumnChunkMetaData {
-    /// Create a new [`ColumnChunkMetaData`]
+    /// Returns a new [`ColumnChunkMetaData`]
     pub fn new(column_chunk: ColumnChunk, column_descr: ColumnDescriptor) -> Self {
         Self {
             column_chunk,
@@ -41,13 +40,14 @@ impl ColumnChunkMetaData {
         self.column_chunk.file_offset
     }
 
-    fn column_metadata(&self) -> &ColumnMetaData {
-        self.column_chunk.meta_data.as_ref().unwrap()
+    /// Returns this column's [`ColumnChunk`]
+    pub fn column_chunk(&self) -> &ColumnChunk {
+        &self.column_chunk
     }
 
-    /// Type of this column. Must be primitive.
-    pub fn type_(&self) -> &Type {
-        &self.column_metadata().type_
+    /// The column's [`ColumnMetaData`]
+    pub fn metadata(&self) -> &ColumnMetaData {
+        self.column_chunk.meta_data.as_ref().unwrap()
     }
 
     /// The [`ColumnDescriptor`] for this column. This descriptor contains the physical and logical type
@@ -56,66 +56,63 @@ impl ColumnChunkMetaData {
         &self.column_descr
     }
 
-    /// The [`ColumnDescriptor`] for this column. This descriptor contains the physical and logical type
-    /// of the pages.
+    /// The [`PhysicalType`] of this column.
     pub fn physical_type(&self) -> PhysicalType {
-        match self.descriptor().type_() {
-            ParquetType::PrimitiveType { physical_type, .. } => *physical_type,
-            _ => unreachable!(),
-        }
+        self.column_descr.descriptor.primitive_type.physical_type
     }
 
-    /// Decodes the raw statistics into a statistics
+    /// Decodes the raw statistics into [`Statistics`].
     pub fn statistics(&self) -> Option<Result<Arc<dyn Statistics>>> {
-        self.column_metadata()
+        self.metadata()
             .statistics
             .as_ref()
-            .map(|x| deserialize_statistics(x, self.descriptor().clone()))
+            .map(|x| deserialize_statistics(x, self.column_descr.descriptor.primitive_type.clone()))
     }
 
-    /// Total number of values in this column chunk.
+    /// Total number of values in this column chunk. Note that this is not necessarily the number
+    /// of rows. E.g. the (nested) array `[[1, 2], [3]]` has 2 rows and 3 values.
     pub fn num_values(&self) -> i64 {
-        self.column_metadata().num_values
+        self.metadata().num_values
     }
 
     /// [`Compression`] for this column.
     pub fn compression(&self) -> Compression {
-        self.column_metadata().codec.try_into().unwrap()
+        self.metadata().codec.try_into().unwrap()
     }
 
     /// Returns the total compressed data size of this column chunk.
     pub fn compressed_size(&self) -> i64 {
-        self.column_metadata().total_compressed_size
+        self.metadata().total_compressed_size
     }
 
     /// Returns the total uncompressed data size of this column chunk.
     pub fn uncompressed_size(&self) -> i64 {
-        self.column_metadata().total_uncompressed_size
+        self.metadata().total_uncompressed_size
     }
 
     /// Returns the offset for the column data.
     pub fn data_page_offset(&self) -> i64 {
-        self.column_metadata().data_page_offset
+        self.metadata().data_page_offset
     }
 
     /// Returns `true` if this column chunk contains a index page, `false` otherwise.
     pub fn has_index_page(&self) -> bool {
-        self.column_metadata().index_page_offset.is_some()
+        self.metadata().index_page_offset.is_some()
     }
 
     /// Returns the offset for the index page.
     pub fn index_page_offset(&self) -> Option<i64> {
-        self.column_metadata().index_page_offset
+        self.metadata().index_page_offset
     }
 
     /// Returns the offset for the dictionary page, if any.
     pub fn dictionary_page_offset(&self) -> Option<i64> {
-        self.column_metadata().dictionary_page_offset
+        self.metadata().dictionary_page_offset
     }
 
     /// Returns the encoding for this column
     pub fn column_encoding(&self) -> &Vec<Encoding> {
-        &self.column_metadata().encodings
+        &self.metadata().encodings
     }
 
     /// Returns the offset and length in bytes of the column chunk within the file
@@ -134,7 +131,7 @@ impl ColumnChunkMetaData {
     }
 
     /// Method to convert from Thrift.
-    pub fn try_from_thrift(
+    pub(crate) fn try_from_thrift(
         column_descr: ColumnDescriptor,
         column_chunk: ColumnChunk,
     ) -> Result<Self> {
