@@ -1,7 +1,10 @@
 use std::{any::Any, sync::Arc};
 
-use crate::error::Result;
-use crate::{schema::types::PhysicalType, types, types::NativeType};
+use crate::error::{Error, Result};
+use crate::{
+    schema::types::PhysicalType,
+    types::{decode, NativeType},
+};
 
 use super::DictPage;
 
@@ -30,11 +33,18 @@ impl<T: NativeType> DictPage for PrimitivePageDict<T> {
     }
 }
 
-fn read_plain<T: NativeType>(values: &[u8]) -> Vec<T> {
+fn read_plain<T: NativeType>(values: &[u8]) -> Result<Vec<T>> {
     // read in plain
-    let chunks = values.chunks_exact(std::mem::size_of::<T>());
-    assert_eq!(chunks.remainder().len(), 0);
-    chunks.map(|chunk| types::decode(chunk)).collect()
+    if values.len() % std::mem::size_of::<T>() != 0 {
+        return Err(Error::OutOfSpec(
+            "A dictionary page with primitive values must contain a multiple of their format."
+                .to_string(),
+        ));
+    }
+    Ok(values
+        .chunks_exact(std::mem::size_of::<T>())
+        .map(decode::<T>)
+        .collect())
 }
 
 pub fn read<T: NativeType>(
@@ -43,6 +53,6 @@ pub fn read<T: NativeType>(
     _is_sorted: bool,
 ) -> Result<Arc<dyn DictPage>> {
     let typed_size = num_values * std::mem::size_of::<T>();
-    let values = read_plain::<T>(&buf[..typed_size]);
+    let values = read_plain::<T>(&buf[..typed_size])?;
     Ok(Arc::new(PrimitivePageDict::new(values)))
 }
