@@ -1,6 +1,6 @@
+use crate::compression::CompressionOptions;
 use crate::error::{Error, Result};
 use crate::page::{CompressedDictPage, CompressedPage, DataPageHeader, EncodedDictPage};
-use crate::parquet_bridge::Compression;
 use crate::FallibleStreamingIterator;
 use crate::{
     compression,
@@ -11,7 +11,7 @@ use crate::{
 fn compress_data(
     page: DataPage,
     mut compressed_buffer: Vec<u8>,
-    compression: Compression,
+    compression: CompressionOptions,
 ) -> Result<CompressedDataPage> {
     let DataPage {
         mut buffer,
@@ -21,7 +21,7 @@ fn compress_data(
         selected_rows,
     } = page;
     let uncompressed_page_size = buffer.len();
-    if compression != Compression::Uncompressed {
+    if compression != CompressionOptions::Uncompressed {
         match &header {
             DataPageHeader::V1(_) => {
                 compression::compress(compression, &buffer, &mut compressed_buffer)?;
@@ -44,7 +44,7 @@ fn compress_data(
     Ok(CompressedDataPage::new_read(
         header,
         compressed_buffer,
-        compression,
+        compression.into(),
         uncompressed_page_size,
         dictionary_page,
         descriptor,
@@ -55,21 +55,21 @@ fn compress_data(
 fn compress_dict(
     page: EncodedDictPage,
     mut compressed_buffer: Vec<u8>,
-    compression: Compression,
+    compression: CompressionOptions,
 ) -> Result<CompressedDictPage> {
     let EncodedDictPage {
         mut buffer,
         num_values,
     } = page;
     let uncompressed_page_size = buffer.len();
-    if compression != Compression::Uncompressed {
+    if compression != CompressionOptions::Uncompressed {
         compression::compress(compression, &buffer, &mut compressed_buffer)?;
     } else {
         std::mem::swap(&mut buffer, &mut compressed_buffer);
     }
     Ok(CompressedDictPage::new(
         compressed_buffer,
-        compression,
+        compression.into(),
         uncompressed_page_size,
         num_values,
     ))
@@ -85,7 +85,7 @@ fn compress_dict(
 pub fn compress(
     page: EncodedPage,
     compressed_buffer: Vec<u8>,
-    compression: Compression,
+    compression: CompressionOptions,
 ) -> Result<CompressedPage> {
     match page {
         EncodedPage::Data(page) => {
@@ -101,19 +101,19 @@ pub fn compress(
 /// holding a reusable buffer ([`Vec<u8>`]) for compression.
 pub struct Compressor<I: Iterator<Item = Result<EncodedPage>>> {
     iter: I,
-    compression: Compression,
+    compression: CompressionOptions,
     buffer: Vec<u8>,
     current: Option<CompressedPage>,
 }
 
 impl<I: Iterator<Item = Result<EncodedPage>>> Compressor<I> {
     /// Creates a new [`Compressor`]
-    pub fn new_from_vec(iter: I, compression: Compression, buffer: Vec<u8>) -> Self {
+    pub fn new_from_vec(iter: I, compression: CompressionOptions, buffer: Vec<u8>) -> Self {
         Self::new(iter, compression, buffer)
     }
 
     /// Creates a new [`Compressor`]
-    pub fn new(iter: I, compression: Compression, buffer: Vec<u8>) -> Self {
+    pub fn new(iter: I, compression: CompressionOptions, buffer: Vec<u8>) -> Self {
         Self {
             iter,
             compression,
