@@ -1,7 +1,8 @@
 mod column_chunk;
 mod compression;
 mod file;
-mod page;
+mod indexes;
+pub(crate) mod page;
 mod row_group;
 pub(self) mod statistics;
 
@@ -19,7 +20,6 @@ pub use file::FileWriter;
 
 pub use row_group::ColumnOffsetsMetadata;
 
-use crate::compression::Compression;
 use crate::page::CompressedPage;
 
 pub type RowGroupIter<'a, E> =
@@ -28,10 +28,8 @@ pub type RowGroupIter<'a, E> =
 /// Write options of different interfaces on this crate
 #[derive(Debug, Copy, Clone, PartialEq, Eq, Hash)]
 pub struct WriteOptions {
-    /// Whether to write statistics
+    /// Whether to write statistics, including indexes
     pub write_statistics: bool,
-    /// Whether to use compression
-    pub compression: Compression,
     /// Which Parquet version to use
     pub version: Version,
 }
